@@ -61,6 +61,19 @@ module RSpec
         an_object.call :my_method
       end
 
+      # This is a regresion test for rspec/rspec#212 / rspec/rspec#213
+      it "supports nesting" do
+        nested = false
+        expect(object).to receive(:nested).twice do
+          unless nested
+            nested = true
+            object.nested
+          end
+        end
+
+        object.nested
+      end
+
       it "can disallow messages from being received" do
         expect(object).not_to receive(:fuhbar)
         expect_fast_failure_from(
@@ -219,7 +232,7 @@ module RSpec
         end
       end
 
-      it "allows `write` to be stubbed and reset", :unless => Support::Ruby.jruby? do
+      it "allows `write` to be stubbed and reset", :skip => Support::Ruby.jruby? do
         allow(file_1).to receive(:write)
         file_1.reopen(file_2)
         expect_output_warning_on_ruby_lt_2 { reset file_1 }
@@ -232,7 +245,7 @@ module RSpec
       end
     end
 
-    RSpec.describe "Using a partial mock on a proxy object", :if => defined?(::BasicObject) do
+    RSpec.describe "Using a partial mock on a proxy object", :skip => !defined?(::BasicObject) do
       let(:proxy_class) do
         Class.new(::BasicObject) do
           def initialize(target)
@@ -646,7 +659,7 @@ module RSpec
         end
 
         context "on a class with a twice-aliased `new`" do
-          it 'uses the method signature from `#initialize` for arg verification', :if => (RUBY_VERSION.to_i >= 3) do
+          it 'uses the method signature from `#initialize` for arg verification', :skip => (RUBY_VERSION.to_i < 3) do
             subclass = Class.new(klass) do
               class << self
                 alias_method :_new, :new
